@@ -268,8 +268,7 @@ static int run_gamemoderun_and_reaper_tests(struct GameModeConfig *config)
 		/* Close stdout, we don't care if sh prints anything */
 		fclose(stdout);
 		/* Preload into sh and then kill it */
-		if (execl("/usr/bin/gamemoderun", "/usr/bin/gamemoderun", "sleep", "5", (char *)NULL) ==
-		    -1) {
+		if (execlp("gamemoderun", "gamemoderun", "sleep", "5", (char *)NULL) == -1) {
 			LOG_ERROR("failed to launch gamemoderun with execl: %s\n", strerror(errno));
 			return -1;
 		}
@@ -370,7 +369,7 @@ static int run_custom_scripts_tests(struct GameModeConfig *config)
 
 	if (startscripts[0][0] != '\0') {
 		int i = 0;
-		while (*startscripts[i] != '\0' && i < CONFIG_LIST_MAX) {
+		while (i < CONFIG_LIST_MAX && *startscripts[i] != '\0') {
 			LOG_MSG(":::: Running start script [%s]\n", startscripts[i]);
 
 			const char *args[] = { "/bin/sh", "-c", startscripts[i], NULL };
@@ -393,7 +392,7 @@ static int run_custom_scripts_tests(struct GameModeConfig *config)
 
 	if (endscripts[0][0] != '\0') {
 		int i = 0;
-		while (*endscripts[i] != '\0' && i < CONFIG_LIST_MAX) {
+		while (i < CONFIG_LIST_MAX && *endscripts[i] != '\0') {
 			LOG_MSG(":::: Running end script [%s]\n", endscripts[i]);
 
 			const char *args[] = { "/bin/sh", "-c", endscripts[i], NULL };
